==> plantuml-libs-9.0.0.tgz: package/distribution/simpleicons-7/S/Sanfranciscomunicipalrailway.md <==
# Sanfranciscomunicipalrailway


```text
simpleicons-7/S/Sanfranciscomunicipalrailway
```

```text
include('simpleicons-7/S/Sanfranciscomunicipalrailway')
```



| Illustration | Sanfranciscomunicipalrailway |
| :---: | :---: |
| ![illustration for Illustration](../../simpleicons-7/S/Sanfranciscomunicipalrailway.png) | ![illustration for Sanfranciscomunicipalrailway](../../simpleicons-7/S/Sanfranciscomunicipalrailway.Local.png) |




## Sanfranciscomunicipalrailway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Sanfranciscomunicipalrailway
include('simpleicons-7/S/Sanfranciscomunicipalrailway')

' renders the element
Sanfranciscomunicipalrailway('Sanfranciscomunicipalrailway', 'Sanfranciscomunicipalrailway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Sanfranciscomunicipalrailway
include('simpleicons-7/S/Sanfranciscomunicipalrailway')

' renders the element
Sanfranciscomunicipalrailway('Sanfranciscomunicipalrailway', 'Sanfranciscomunicipalrailway', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/simpleicons-7/S/Sanfranciscomunicipalrailway.md <==
# Sanfranciscomunicipalrailway


```text
simpleicons-7/S/Sanfranciscomunicipalrailway
```

```text
include('simpleicons-7/S/Sanfranciscomunicipalrailway')
```



| Illustration | Sanfranciscomunicipalrailway |
| :---: | :---: |
| ![illustration for Illustration](../../simpleicons-7/S/Sanfranciscomunicipalrailway.png) | ![illustration for Sanfranciscomunicipalrailway](../../simpleicons-7/S/Sanfranciscomunicipalrailway.Local.png) |




## Sanfranciscomunicipalrailway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Sanfranciscomunicipalrailway
include('simpleicons-7/S/Sanfranciscomunicipalrailway')

' renders the element
Sanfranciscomunicipalrailway('Sanfranciscomunicipalrailway', 'Sanfranciscomunicipalrailway', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Sanfranciscomunicipalrailway
include('simpleicons-7/S/Sanfranciscomunicipalrailway')

' renders the element
Sanfranciscomunicipalrailway('Sanfranciscomunicipalrailway', 'Sanfranciscomunicipalrailway', 'an optional tech label', 'an optional description')
@enduml
```
